Explicit helper APIs that may allocate.
These helpers are intentionally separated from the zero-copy bridge path.
Functions
- cast_
f32_ to_ f64 - Casts
PrimitiveArray<f32>toPrimitiveArray<f64>. - cast_
f64_ to_ f32 - Casts
PrimitiveArray<f64>toPrimitiveArray<f32>. - compact_
non_ null - Compacts a primitive array by removing null positions.
- densify_
csr_ view - Densifies a CSR view into an Arrow
FixedSizeListArray. - fill_
nulls_ with_ mean - Fills nulls in a primitive array with the mean of non-null values.
- fill_
nulls_ with_ zero - Fills nulls in a primitive array with the additive identity (
0). - reshape_
primitive_ to_ array2 - Reinterprets a primitive Arrow array as a 2D ndarray view.
- reshape_
primitive_ to_ arrayd - Reinterprets a primitive Arrow array as an ND ndarray view.
- to_
standard_ layout - Converts an owned ndarray array to standard (C-contiguous) layout.