pub unsafe fn fixed_size_list_as_array2_unchecked<T>(
array: &FixedSizeListArray,
) -> ArrayView2<'_, T::Native>Expand description
Zero-copy conversion from a FixedSizeListArray to an ArrayView2, without null checks.
Safety
The caller must guarantee that neither the outer array nor the inner values array contains null values.
Does not allocate
Panics
Panics if:
- the inner values are not a
PrimitiveArray<T>; value_lengthis negative;- or Arrow’s
(rows, value_length)invariant is violated.